﻿param($installPath, $toolsPath, $package, $project)

Import-Module (Join-Path $toolsPath "Get-ConfigPath.psm1")
Import-Module (Join-Path $toolsPath "Get-Config.psm1")
Import-Module (Join-Path $toolsPath "Update-AssemblyBinding.psm1")
Import-Module (Join-Path $toolsPath "Expand-Zip.psm1")
Import-Module (join-path $toolsPath  "Get-PackagesToolPath.psm1")
Import-Module (join-path $toolsPath  "Get-EPiServerCommerceConnectionString.psm1")
Import-Module (join-path $toolsPath  "Copy-EcfConfigsIfNotExist.psm1")
Import-Module (join-path $toolsPath  "Set-ConnectionStringUsingProjectsInSameSolution.psm1")
Import-Module (join-path $toolsPath  "Update-CommerceManagerLink.psm1")
Import-Module (join-path $toolsPath  "Set-CommerceManagerSearchIndexBasePath.psm1")
Import-Module (join-path $toolsPath  "Set-CommerceManagerSharedNotificationTemplatesPath.psm1")

Function RemoveInvalidHttpModulePreCondition([System.Xml.XmlDocument]$config)
{
	$invalidModules = $config.SelectNodes("/configuration/system.web/httpModules/add[@preCondition]")
	foreach ($module in $invalidModules)
	{
		Write-Host "Removing invalid preCondition attribute of httpModule".
		$module.RemoveAttribute("preCondition") | Out-Null
	}
}

Function RemoveMediachaseCmsAssembly([System.Xml.XmlDocument]$config)
{    
    $ns = New-Object Xml.XmlNamespaceManager $config.NameTable
    $ns.AddNamespace( "x", "urn:schemas-microsoft-com:asm.v1" )
    $xpath = "/configuration/runtime/x:assemblyBinding/x:dependentAssembly[x:assemblyIdentity/@name='Mediachase.Cms']"
    $mediachaseCmsAssembly = $config.SelectSingleNode($xpath, $ns)
    if($mediachaseCmsAssembly -ne $null)
    {
        Write-Host "Removing Mediachase Cms Assembly"
        $mediachaseCmsAssembly.ParentNode.RemoveChild($mediachaseCmsAssembly);
    }    	
}

Function RemoveObsoleteFiles([String] $sitePath)
{
	#Remove obsolete files relate to Mediachase.Cms		
	$mediachaseCmsDllPath = Join-Path $sitePath "bin\Mediachase.Cms.*";
	if(Test-Path($mediachaseCmsDllPath)) {
		Write-Host "Removing file $mediachaseCmsDllPath"
		Remove-Item $mediachaseCmsDllPath
	}		
	
	$mediachaseCmsContentFolder = Join-Path $sitePath "Apps\Content";
	if(Test-Path($mediachaseCmsContentFolder)) {
		Write-Host "Removing folder $mediachaseCmsContentFolder"
		Remove-Item $mediachaseCmsContentFolder -Recurse
	}		
}

Function RemoveAssetFolder([String] $sitePath)
{ 
    $assetFolder = Join-Path $sitePath "Apps\Asset";
    if(Test-Path($assetFolder)) {
        Write-Host "Removing folder $assetFolder"
        Remove-Item $assetFolder -Recurse
    }       
}

#Get the Framework package
$frameworkPackage = Get-package -ProjectName $project.ProjectName | where-object { $_.id -eq "EPiServer.Framework"} | Sort-Object -Property Version -Descending | select-object -first 1
$frameWorkToolPath = Get-PackagesToolPath $installPath "EPiServer.Framework" $frameworkPackage.Version
$deployEXEPath =  join-Path ($frameWorkToolPath) "epideploy.exe"

$projectFilePath = Get-ChildItem $project.Fullname
$sitePath = $projectFilePath.Directory.FullName

#copy EPiServerLog.config without overwriting
$episerverLogConfigPath =[System.IO.Path]::Combine($installPath, "tools\EPiServerLog.config")
if (!(Test-Path (Join-Path $sitePath "EPiServerLog.config")))
{
	Copy-Item $episerverLogConfigPath -Destination $sitePath
}

$projectFile = Get-Item $project.FullName
$destination = $projectFile.Directory.FullName

#add/update binding redirects for assemblies in the current package
$commerceConfigBaselinePath =[System.IO.Path]::Combine($installPath, "tools\webconfig-baseline.config")
$commerceConfigUpdatePath =[System.IO.Path]::Combine($installPath, "tools\webconfig-update.config")
$configPath = Get-ConfigPath $project
if ($configPath -eq $null)
{
	Write-Host "Unable to find a configuration file, binding redirect not configured."
}
else
{
    $config = Get-Config $configPath
    Update-AssemblyBinding $config $installPath | Out-Null

    #Also remove invalid preCondition attribute added by 7.5 install/upgrade
    RemoveInvalidHttpModulePreCondition $config
    #Remove Mediachase.cms dependentAssembly from webconfig of upgrade site
    RemoveMediachaseCmsAssembly $config
    $config.Save($configPath)

    RemoveObsoleteFiles $sitePath

    RemoveAssetFolder $sitePath
    
    ## Install baseline if not already added
    $epiConnection = Get-EPiServerCommerceConnectionString($configPath)
    if ($epiConnection -eq $null)
    {
        Write-Host "Adding Commerce baseline configuration"
        & $deployEXEPath -s $sitePath -a config -p $commerceConfigBaselinePath
        
        # get the active solution
        $solution = Get-Interface $dte.Solution ([EnvDTE80.Solution2])
        
        $config = Get-Config $configPath

        # Modify ConnectionString if version only supports LocalDB\v11.0
        $vsVersion = [System.Version]::Parse($project.DTE.Version)
        $localDBDataSource = if ($vsVersion.Major -lt 14) { "(LocalDb)\v11.0" } else { "(LocalDb)\MSSQLLocalDB" }

        Set-CommerceManagerSharedNotificationTemplatesPath $config $destination
        Set-ConnectionStringUsingProjectsInSameSolution $solution $config "EcfSqlConnection" $localDBDataSource
        Set-ConnectionStringUsingProjectsInSameSolution $solution $config "EPiServerDB" $localDBDataSource
        $config.Save($configPath)
        
        Update-CommerceManagerLink $solution $project

        #Update search config
        $searchConfigPath = Join-Path $toolsPath "Configs\Mediachase.Search.Config"
        $searchIndexBasePath = "[appDataPath]\Search\ECApplication\"
        $searchConfig = Get-Config $searchConfigPath
        Set-CommerceManagerSearchIndexBasePath $searchConfig $searchIndexBasePath
        $searchConfig.Save($searchConfigPath)
    }
    Write-Host "Adding Commerce update configuration"
    & $deployEXEPath -s $sitePath -a config -p $commerceConfigUpdatePath
}

Copy-EcfConfigsIfNotExist $project $toolsPath $sitePath

$marketingFolder = join-path $sitePath "Apps\Marketing"
Remove-Item $marketingFolder -Recurse -ErrorAction Ignore

$zipFilePath = join-path $toolsPath "EPiServer.CommerceManager.zip"
Expand-Zip $zipFilePath $destination
# SIG # Begin signature block
# MIIVlQYJKoZIhvcNAQcCoIIVhjCCFYICAQExCzAJBgUrDgMCGgUAMGkGCisGAQQB
# gjcCAQSgWzBZMDQGCisGAQQBgjcCAR4wJgIDAQAABBAfzDtgWUsITrck0sYpfvNR
# AgEAAgEAAgEAAgEAAgEAMCEwCQYFKw4DAhoFAAQUU10nX29vLippvNGdeE3sx3BJ
# /p+gghH2MIIFbzCCBFegAwIBAgIQSPyTtGBVlI02p8mKidaUFjANBgkqhkiG9w0B
# AQwFADB7MQswCQYDVQQGEwJHQjEbMBkGA1UECAwSR3JlYXRlciBNYW5jaGVzdGVy
# MRAwDgYDVQQHDAdTYWxmb3JkMRowGAYDVQQKDBFDb21vZG8gQ0EgTGltaXRlZDEh
# MB8GA1UEAwwYQUFBIENlcnRpZmljYXRlIFNlcnZpY2VzMB4XDTIxMDUyNTAwMDAw
# MFoXDTI4MTIzMTIzNTk1OVowVjELMAkGA1UEBhMCR0IxGDAWBgNVBAoTD1NlY3Rp
# Z28gTGltaXRlZDEtMCsGA1UEAxMkU2VjdGlnbyBQdWJsaWMgQ29kZSBTaWduaW5n
# IFJvb3QgUjQ2MIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAjeeUEiIE
# JHQu/xYjApKKtq42haxH1CORKz7cfeIxoFFvrISR41KKteKW3tCHYySJiv/vEpM7
# fbu2ir29BX8nm2tl06UMabG8STma8W1uquSggyfamg0rUOlLW7O4ZDakfko9qXGr
# YbNzszwLDO/bM1flvjQ345cbXf0fEj2CA3bm+z9m0pQxafptszSswXp43JJQ8mTH
# qi0Eq8Nq6uAvp6fcbtfo/9ohq0C/ue4NnsbZnpnvxt4fqQx2sycgoda6/YDnAdLv
# 64IplXCN/7sVz/7RDzaiLk8ykHRGa0c1E3cFM09jLrgt4b9lpwRrGNhx+swI8m2J
# mRCxrds+LOSqGLDGBwF1Z95t6WNjHjZ/aYm+qkU+blpfj6Fby50whjDoA7NAxg0P
# OM1nqFOI+rgwZfpvx+cdsYN0aT6sxGg7seZnM5q2COCABUhA7vaCZEao9XOwBpXy
# bGWfv1VbHJxXGsd4RnxwqpQbghesh+m2yQ6BHEDWFhcp/FycGCvqRfXvvdVnTyhe
# Be6QTHrnxvTQ/PrNPjJGEyA2igTqt6oHRpwNkzoJZplYXCmjuQymMDg80EY2NXyc
# uu7D1fkKdvp+BRtAypI16dV60bV/AK6pkKrFfwGcELEW/MxuGNxvYv6mUKe4e7id
# FT/+IAx1yCJaE5UZkADpGtXChvHjjuxf9OUCAwEAAaOCARIwggEOMB8GA1UdIwQY
# MBaAFKARCiM+lvEH7OKvKe+CpX/QMKS0MB0GA1UdDgQWBBQy65Ka/zWWSC8oQEJw
# IDaRXBeF5jAOBgNVHQ8BAf8EBAMCAYYwDwYDVR0TAQH/BAUwAwEB/zATBgNVHSUE
# DDAKBggrBgEFBQcDAzAbBgNVHSAEFDASMAYGBFUdIAAwCAYGZ4EMAQQBMEMGA1Ud
# HwQ8MDowOKA2oDSGMmh0dHA6Ly9jcmwuY29tb2RvY2EuY29tL0FBQUNlcnRpZmlj
# YXRlU2VydmljZXMuY3JsMDQGCCsGAQUFBwEBBCgwJjAkBggrBgEFBQcwAYYYaHR0
# cDovL29jc3AuY29tb2RvY2EuY29tMA0GCSqGSIb3DQEBDAUAA4IBAQASv6Hvi3Sa
# mES4aUa1qyQKDKSKZ7g6gb9Fin1SB6iNH04hhTmja14tIIa/ELiueTtTzbT72ES+
# BtlcY2fUQBaHRIZyKtYyFfUSg8L54V0RQGf2QidyxSPiAjgaTCDi2wH3zUZPJqJ8
# ZsBRNraJAlTH/Fj7bADu/pimLpWhDFMpH2/YGaZPnvesCepdgsaLr4CnvYFIUoQx
# 2jLsFeSmTD1sOXPUC4U5IOCFGmjhp0g4qdE2JXfBjRkWxYhMZn0vY86Y6GnfrDyo
# XZ3JHFuu2PMvdM+4fvbXg50RlmKarkUT2n/cR/vfw1Kf5gZV6Z2M8jpiUbzsJA8p
# 1FiAhORFe1rYMIIGGjCCBAKgAwIBAgIQYh1tDFIBnjuQeRUgiSEcCjANBgkqhkiG
# 9w0BAQwFADBWMQswCQYDVQQGEwJHQjEYMBYGA1UEChMPU2VjdGlnbyBMaW1pdGVk
# MS0wKwYDVQQDEyRTZWN0aWdvIFB1YmxpYyBDb2RlIFNpZ25pbmcgUm9vdCBSNDYw
# HhcNMjEwMzIyMDAwMDAwWhcNMzYwMzIxMjM1OTU5WjBUMQswCQYDVQQGEwJHQjEY
# MBYGA1UEChMPU2VjdGlnbyBMaW1pdGVkMSswKQYDVQQDEyJTZWN0aWdvIFB1Ymxp
# YyBDb2RlIFNpZ25pbmcgQ0EgUjM2MIIBojANBgkqhkiG9w0BAQEFAAOCAY8AMIIB
# igKCAYEAmyudU/o1P45gBkNqwM/1f/bIU1MYyM7TbH78WAeVF3llMwsRHgBGRmxD
# eEDIArCS2VCoVk4Y/8j6stIkmYV5Gej4NgNjVQ4BYoDjGMwdjioXan1hlaGFt4Wk
# 9vT0k2oWJMJjL9G//N523hAm4jF4UjrW2pvv9+hdPX8tbbAfI3v0VdJiJPFy/7Xw
# iunD7mBxNtecM6ytIdUlh08T2z7mJEXZD9OWcJkZk5wDuf2q52PN43jc4T9OkoXZ
# 0arWZVeffvMr/iiIROSCzKoDmWABDRzV/UiQ5vqsaeFaqQdzFf4ed8peNWh1OaZX
# nYvZQgWx/SXiJDRSAolRzZEZquE6cbcH747FHncs/Kzcn0Ccv2jrOW+LPmnOyB+t
# AfiWu01TPhCr9VrkxsHC5qFNxaThTG5j4/Kc+ODD2dX/fmBECELcvzUHf9shoFvr
# n35XGf2RPaNTO2uSZ6n9otv7jElspkfK9qEATHZcodp+R4q2OIypxR//YEb3fkDn
# 3UayWW9bAgMBAAGjggFkMIIBYDAfBgNVHSMEGDAWgBQy65Ka/zWWSC8oQEJwIDaR
# XBeF5jAdBgNVHQ4EFgQUDyrLIIcouOxvSK4rVKYpqhekzQwwDgYDVR0PAQH/BAQD
# AgGGMBIGA1UdEwEB/wQIMAYBAf8CAQAwEwYDVR0lBAwwCgYIKwYBBQUHAwMwGwYD
# VR0gBBQwEjAGBgRVHSAAMAgGBmeBDAEEATBLBgNVHR8ERDBCMECgPqA8hjpodHRw
# Oi8vY3JsLnNlY3RpZ28uY29tL1NlY3RpZ29QdWJsaWNDb2RlU2lnbmluZ1Jvb3RS
# NDYuY3JsMHsGCCsGAQUFBwEBBG8wbTBGBggrBgEFBQcwAoY6aHR0cDovL2NydC5z
# ZWN0aWdvLmNvbS9TZWN0aWdvUHVibGljQ29kZVNpZ25pbmdSb290UjQ2LnA3YzAj
# BggrBgEFBQcwAYYXaHR0cDovL29jc3Auc2VjdGlnby5jb20wDQYJKoZIhvcNAQEM
# BQADggIBAAb/guF3YzZue6EVIJsT/wT+mHVEYcNWlXHRkT+FoetAQLHI1uBy/YXK
# ZDk8+Y1LoNqHrp22AKMGxQtgCivnDHFyAQ9GXTmlk7MjcgQbDCx6mn7yIawsppWk
# vfPkKaAQsiqaT9DnMWBHVNIabGqgQSGTrQWo43MOfsPynhbz2Hyxf5XWKZpRvr3d
# MapandPfYgoZ8iDL2OR3sYztgJrbG6VZ9DoTXFm1g0Rf97Aaen1l4c+w3DC+IkwF
# kvjFV3jS49ZSc4lShKK6BrPTJYs4NG1DGzmpToTnwoqZ8fAmi2XlZnuchC4NPSZa
# PATHvNIzt+z1PHo35D/f7j2pO1S8BCysQDHCbM5Mnomnq5aYcKCsdbh0czchOm8b
# kinLrYrKpii+Tk7pwL7TjRKLXkomm5D1Umds++pip8wH2cQpf93at3VDcOK4N7Ew
# oIJB0kak6pSzEu4I64U6gZs7tS/dGNSljf2OSSnRr7KWzq03zl8l75jy+hOds9TW
# SenLbjBQUGR96cFr6lEUfAIEHVC1L68Y1GGxx4/eRI82ut83axHMViw1+sVpbPxg
# 51Tbnio1lB93079WPFnYaOvfGAA0e0zcfF/M9gXr+korwQTh2Prqooq2bYNMvUoU
# KD85gnJ+t0smrWrb8dee2CvYZXD5laGtaAxOfy/VKNmwuWuAh9kcMIIGYTCCBMmg
# AwIBAgIQXAGgVVp6Ap+6PaMsqZRj/DANBgkqhkiG9w0BAQwFADBUMQswCQYDVQQG
# EwJHQjEYMBYGA1UEChMPU2VjdGlnbyBMaW1pdGVkMSswKQYDVQQDEyJTZWN0aWdv
# IFB1YmxpYyBDb2RlIFNpZ25pbmcgQ0EgUjM2MB4XDTIyMDUxODAwMDAwMFoXDTI1
# MDUxNzIzNTk1OVowVTELMAkGA1UEBhMCU0UxGDAWBgNVBAgMD1N0b2NraG9sbXMg
# bMOkbjEVMBMGA1UECgwMRXBpc2VydmVyIEFCMRUwEwYDVQQDDAxFcGlzZXJ2ZXIg
# QUIwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQCojYASngXIv2En9aBr
# hDwGjFDZzyFjwd2bskGnQzn2nWtAmUvwF5c6SlI6pMk4I7nUkdKrZ3qMGOxyr0g2
# Ht2R4jW3hnbGwEbclauNF/pqcXfDy+eTcANBe4HVdMTd/jOcvAg5Zhszjk0KNRl3
# XxUORj7eWgfX96ndsJNn/sD07GkS8ZFHXTEyoOW26/eJ0qOGRWlMNrIc3JnoGHjS
# RrYJmjsjgoHDOVmZrJRfUOU7xWuexNaHWxDHt4rpGfjkaazw7NMFZxT4+X9R8B/k
# 5qFaPcDr/eZnIJVlNSdz9UQxF2J/LEbS7a207Tseq5Tx4kWkPYXkZnJB8DHOz3OZ
# ejIlNFSvA2m16JxEn++LazZZy+G0gkLYVNVbX1dgskVWJrqS4WVGLjAczqeBtVQ8
# KxsUEfyNM9t010s/b9Ac3CSrCHVOxdWSbAno4SezYI4a2gJMZOEZKzcZ0xH237bi
# EQFufY/iE63nFqtPgFxsivyUazs0I1Tic2qu/6q4drabD/vEBjU7RM7BsOUvqJLY
# 53k3MyURJLEgTFy1NtB4MUa7CTiIVLHlPwW9/KF6VzGzXABLnKhekYF7eVRJvrfD
# jNP22WC2VVy5sOxTOoCnSGa8KDw9JLBDwW9RgbufcNY9E569s/qwq35PJiljEHMM
# 4sofFu9pY2d1iGOTJ2p4Vpg5QQIDAQABo4IBrDCCAagwHwYDVR0jBBgwFoAUDyrL
# IIcouOxvSK4rVKYpqhekzQwwHQYDVR0OBBYEFN3YgPa91L0oKYWS5rSzX36XJxrG
# MA4GA1UdDwEB/wQEAwIHgDAMBgNVHRMBAf8EAjAAMBMGA1UdJQQMMAoGCCsGAQUF
# BwMDMEoGA1UdIARDMEEwNQYMKwYBBAGyMQECAQMCMCUwIwYIKwYBBQUHAgEWF2h0
# dHBzOi8vc2VjdGlnby5jb20vQ1BTMAgGBmeBDAEEATBJBgNVHR8EQjBAMD6gPKA6
# hjhodHRwOi8vY3JsLnNlY3RpZ28uY29tL1NlY3RpZ29QdWJsaWNDb2RlU2lnbmlu
# Z0NBUjM2LmNybDB5BggrBgEFBQcBAQRtMGswRAYIKwYBBQUHMAKGOGh0dHA6Ly9j
# cnQuc2VjdGlnby5jb20vU2VjdGlnb1B1YmxpY0NvZGVTaWduaW5nQ0FSMzYuY3J0
# MCMGCCsGAQUFBzABhhdodHRwOi8vb2NzcC5zZWN0aWdvLmNvbTAhBgNVHREEGjAY
# gRZzdXBwb3J0QG9wdGltaXplbHkuY29tMA0GCSqGSIb3DQEBDAUAA4IBgQBImWGe
# xutmpiCGn//9K7MHWrZCHZsoKj62hZGb8jnqIizod7LculgKVTJIX7wLU0IhJnTt
# EPR0GCstRkBA7U65D8fbmT9RhqnDHA/+rAuU3NulNbmOGAM5tLL7yvbo3+8EcWjv
# acu8eOXeaG3O/CGGh98ph94akvkjg/YlUYuKE8jYUtc07gVS6GLzJx5x5nz4aBu2
# 0C9gcG5D5XM/IWQWrQhoCbvRxpUoJpOe+GSjA38lCM2f+Ch5JUmNfA2bVn2yrElT
# pGkydHtL3Wdkfr86uwSAWUu2CkaxYNHBmQ0u9wmQhPoQQu8XLZlp6a7bR7hSyPnW
# +BF8vwOaeMP89n+v1h5PaDWHFtPLLUklqlSDbicz3QhUtrIjCNRtXdNnPTR7CwCt
# p3uzdqpxIWbuZ0B8pPEdrTfF45TyHydkjyVkeU8zmwS7BangrG2Ae2/hn67CvROI
# 7btx10+CA2kj8UV6zla/icwrvyxcmre70goyhQQ37/8EbodVOaIiTFL5NewxggMJ
# MIIDBQIBATBoMFQxCzAJBgNVBAYTAkdCMRgwFgYDVQQKEw9TZWN0aWdvIExpbWl0
# ZWQxKzApBgNVBAMTIlNlY3RpZ28gUHVibGljIENvZGUgU2lnbmluZyBDQSBSMzYC
# EFwBoFVaegKfuj2jLKmUY/wwCQYFKw4DAhoFAKB4MBgGCisGAQQBgjcCAQwxCjAI
# oAKAAKECgAAwGQYJKoZIhvcNAQkDMQwGCisGAQQBgjcCAQQwHAYKKwYBBAGCNwIB
# CzEOMAwGCisGAQQBgjcCARUwIwYJKoZIhvcNAQkEMRYEFFUVz4EKDMcaaGqU5d+N
# jvJ6/mdmMA0GCSqGSIb3DQEBAQUABIICAHxGSGG5E7D2U8PPc6UFr6PSYdiNsRvJ
# LwBKmQR5W42A/1BrFVROOk13PRsu4oTZqROk8LO7Fgag2iSZ+VtScIKihlWYYcpl
# DoRVByXVYYGlk/d+muerw7v2xUe6lJ8aS96IUl5FsMd6gPqr7cfTWg6UBzORgtqx
# hkL4Nf3ejBTNILtrgXfZoRIbCSaOSpN9G42Mpa5f5dJhzijpkZBFgTO7CMhpKbbG
# 0EsYjV+xt+f4lCt2eJjon+fTTm8DtK0Hnj+watWq8PEnNt5ZYK4l8EHACu0KV6i+
# AhyLlTDsrpwmBLbNAw3oLzxTPzey/M2fY8n+HcexXu0MEVZRkObJ0zC5qzKgb52X
# qQFMt6QQsEj5UjN05yBgsDnsbTi/fxUp7+Nn6bvb/S/Jb2Vc7OONSj75n1EUjedl
# adquQ32x2QYx2x0CgAKrcNykNZfjwIMtagT3BXKwpJkiIakzlhceycqj8CT0vbvz
# RuqPE0XVA/Sm5Qx7MZjKdbz4DVQen3ohd7LjwSsbGL6Cp9xTl8yv9A2wjdAYkUot
# +LVgrAba4WBGhLy16w2iDqIDnmQlidnhkVxAgD5PrR/XLHcQsADNJtNMzIji9PZB
# wtyyJ/OQ1kdV2qfEZFqQRfkoRXVjNuLkXIZNP1c+ypHHWSWnFzwtA9gjFKIq6sEC
# T61lf+CwWZ5M
# SIG # End signature block
